/*
** Copyright (c) 2010  Kimmo 'Rainy' Pekkola
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see http://www.gnu.org/licenses.
*/

#ifndef PRECOMPILED_H
#define PRECOMPILED_H

#include <QtCore>
#include <QtGui>

#ifdef Q_WS_MAEMO_5
#include <libosso.h>
#endif

#ifdef WITH_OPENGL
#include <QGLWidget>
#endif

#ifdef WITH_PHONON
#include <phonon/mediaobject.h>
#endif

#endif // PRECOMPILED_H
